Introduction
============

With the **hydromt_wflow plugin**, users can easily benefit from the rich set of tools of the 
`HydroMT package <https://github.com/Deltares/hydromt>`_ to build and update 
`wflow <https://github.com/Deltares/Wflow.jl>`_ models from available global and local data.

This plugin assists the wflow modeller in:

- Quickly setting up a base wflow model and default parameter values
- Making maximum use of the best available global or local data
- Adjusting and updating components of a wflow model and their associated parameters in a consistent way
- Clipping existing wflow models for a smaller extent
- Analysing wflow model outputs
